@@ -1,6 +1,6 @@
 /*
     constants.h : espctag
-    v0.2 - 2011-07-04
+    v0.3 - 2011-09-19
     
     Copyright (C) 2011 Jérôme SONRIER <jsid@emor3j.fr.eu.org>
 
@@ -20,8 +20,19 @@
     along with espctag.  If not, see <http://www.gnu.org/licenses/>.
 */
 
+/* Tags index */
+#define I_SONG_TITLE  0
+#define I_GAME_TITLE  1
+#define I_DUMPER_NAME 2
+#define I_COMMENTS    3
+#define I_DUMP_DATE   4
+#define I_LENGTH      5
+#define I_FADE_LENGTH 6
+#define I_ARTIST      7
+#define I_CHANNELS    8
+#define I_EMULATOR    9
 
-// Return codes
+/* Return codes */
 #define SUCCESS 0
 #define E_WRONG_ARG -100
-#define E_OPEN_FILE -200
\ No newline at end of file
+#define E_OPEN_FILE -200
